# License Information

This software is licensed under [MPL - Mozilla Public License - Version
2.0](https://mozilla.org/MPL/2.0/) and uses the following 3rd party components.


## Pytest

Optional for running the test, not integrated into the final product.

- [Pytest_LICENSE](./3rd_party_terms_and_licenses/Pytest_LICENSE)
- Download: <https://pypi.org/project/pytest/>

## Black

Optional for formatting the code, not integrated into the final product.

- [Black_LICENSE](./3rd_party_terms_and_licenses/Black_LICENSE)
- Download: <https://pypi.org/project/black/>

## lxml

For parsing input file.

- [Lxml_LICENSE](./3rd_party_terms_and_licenses/Lxml_LICENSE)
- Download: <https://pypi.org/project/lxml/>
